@@ -23,11 +23,11 @@ import logging
 import threading
 
 from oslo_utils import encodeutils
-from oslo_utils import excutils
 from oslo_utils import netutils
 from oslo_utils import timeutils
 import six
 from stevedore import driver
+import tenacity
 
 import tooz
 from tooz import _retry
@@ -59,7 +59,7 @@ class Characteristics(enum.Enum):
     """The driver has the following property:
 
     * Its operations are not based on the timeout of other clients, but on some
-    other more robust mechanisms.
+      other more robust mechanisms.
     """
 
     LINEARIZABLE = 'LINEARIZABLE'
@@ -179,12 +179,15 @@ class Heart(object):
         return not (self._runner is None
                     or not self._runner.is_alive())
 
-    @excutils.forever_retry_uncaught_exceptions
     def _beat_forever_until_stopped(self):
         """Inner beating loop."""
+        retry = tenacity.Retrying(
+            wait=tenacity.wait_fixed(1),
+            before_sleep=tenacity.before_sleep_log(LOG, logging.warning),
+        )
         while not self._dead.is_set():
             with timeutils.StopWatch() as w:
-                wait_until_next_beat = self._driver.heartbeat()
+                wait_until_next_beat = retry(self._driver.heartbeat)
             ran_for = w.elapsed()
             has_to_sleep_for = wait_until_next_beat - ran_for
             if has_to_sleep_for < 0:
@@ -636,7 +639,7 @@ class CoordAsyncResult(object):
     """
 
     @abc.abstractmethod
-    def get(self, timeout=10):
+    def get(self, timeout=None):
         """Retrieve the result of the corresponding asynchronous call.
 
         :param timeout: block until the timeout expire.
